@@ -56,6 +56,28 @@ impl KeyPair {
         unsafe { zig::keygen(pk.as_mut_ptr(), sk.as_mut_ptr()) };
         Self { pk, sk }
     }
+
+    /// Serialize a key pair to bytes
+    pub fn to_bytes(&self) -> [u8; 64] {
+        let mut buf = [0u8; 64];
+        buf[0..31].copy_from_slice(&self.pk);
+        buf[32..63].copy_from_slice(&self.sk);
+        return buf;
+    }
+
+    /// Deserialize a key pair from bytes
+    pub fn from_bytes(&self, buf: &[u8; 64]) -> Self {
+        let mut pk = [0u8; 32];
+        let mut sk = [0u8; 32];
+        pk.copy_from_slice(&buf[0..31]);
+        sk.copy_from_slice(&buf[32..63]);
+        Self { pk, sk }
+    }
+
+    /// Create a key pair from components
+    pub fn new(pk: PublicKey, sk: SecretKey) -> Self {
+        Self { pk, sk }
+    }
 }
 
 /// Number of additional bytes in a ciphertext compared to the corresponding plaintext
@@ -135,7 +157,7 @@ mod test {
             0x12, 0x67, 0x18, 0xf4, 0x4d, 0x63, 0x41, 0x1d, 0x6d, 0xb4, 0xa9, 0x68, 0xb2, 0xe7,
             0xa5, 0x64, 0x22, 0x3a,
         ];
-        let recipient_kp = sealed_box::KeyPair { pk, sk };
+        let recipient_kp = sealed_box::KeyPair::new(pk, sk);
 
         // Message to send
         let msg = b"test";
